==> gemforged-3.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/entity/GemforgedEntities.java <==
package net.trique.gemforged.entity;

import net.fabricmc.fabric.api.object.builder.v1.entity.FabricEntityTypeBuilder;
import net.minecraft.class_1299;
import net.minecraft.class_1311;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_4048;
import net.minecraft.class_7923;
import net.trique.gemforged.Gemforged;

public class GemforgedEntities {

    public static final class_1299<ThunderPrismEntity> THUNDER_PRISM =
            class_2378.method_10230(
                    class_7923.field_41177,
                    new class_2960(Gemforged.MOD_ID, "thunder_prism"),
                    FabricEntityTypeBuilder.<ThunderPrismEntity>create(class_1311.field_17715, ThunderPrismEntity::new)
                            .dimensions(class_4048.method_18385(0.5F, 0.5F))
                            .trackRangeBlocks(8)
                            .trackedUpdateRate(1)
                            .build()
            );

    public static final class_1299<VerdantTotemEntity> VERDANT_TOTEM =
            class_2378.method_10230(
                    class_7923.field_41177,
                    new class_2960(Gemforged.MOD_ID, "verdant_totem"),
                    FabricEntityTypeBuilder.<VerdantTotemEntity>create(class_1311.field_17715, VerdantTotemEntity::new)
                            .dimensions(class_4048.method_18385(0.5F, 0.5F))
                            .trackRangeBlocks(8)
                            .trackedUpdateRate(1)
                            .build()
            );

    public static void registerEntities() {
        Gemforged.LOGGER.info("Registering entities for " + Gemforged.MOD_ID);
    }
}

==> gemforged-4.0.0%2Bmc1.20.1-sources.jar: net/trique/gemforged/entity/GemforgedEntities.java <==
package net.trique.gemforged.entity;

import net.fabricmc.fabric.api.object.builder.v1.entity.FabricEntityTypeBuilder;
import net.minecraft.class_1299;
import net.minecraft.class_1311;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_4048;
import net.minecraft.class_7923;
import net.trique.gemforged.Gemforged;

public class GemforgedEntities {

    public static final class_1299<ThunderPrismEntity> THUNDER_PRISM =
            class_2378.method_10230(
                    class_7923.field_41177,
                    new class_2960(Gemforged.MOD_ID, "thunder_prism"),
                    FabricEntityTypeBuilder.<ThunderPrismEntity>create(class_1311.field_17715, ThunderPrismEntity::new)
                            .dimensions(class_4048.method_18385(0.5F, 0.5F))
                            .trackRangeBlocks(8)
                            .trackedUpdateRate(1)
                            .build()
            );

    public static final class_1299<VerdantTotemEntity> VERDANT_TOTEM =
            class_2378.method_10230(
                    class_7923.field_41177,
                    new class_2960(Gemforged.MOD_ID, "verdant_totem"),
                    FabricEntityTypeBuilder.<VerdantTotemEntity>create(class_1311.field_17715, VerdantTotemEntity::new)
                            .dimensions(class_4048.method_18385(0.5F, 0.5F))
                            .trackRangeBlocks(8)
                            .trackedUpdateRate(1)
                            .build()
            );

    public static final class_1299<GhostArrowEntity> GHOST_ARROW =
            class_2378.method_10230(
                    class_7923.field_41177,
                    new class_2960(Gemforged.MOD_ID, "ghost_arrow"),
                    FabricEntityTypeBuilder.<GhostArrowEntity>create(class_1311.field_17715, GhostArrowEntity::new)
                            .dimensions(class_4048.method_18385(0.5F, 0.5F))
                            .trackRangeBlocks(64)
                            .trackedUpdateRate(20)
                            .build()
            );

    public static void registerEntities() {
        Gemforged.LOGGER.info("Registering entities for " + Gemforged.MOD_ID);
    }
}
